==> estateplat-common-1.2.3-20180710.065627-144-sources.jar: cn/gtmap/estateplat/model/exchange/national/KttLpbFwHs.java <==
package cn.gtmap.estateplat.model.exchange.national;

import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;

/**
 * @author <a href="mailto:sunchao@gtmap.cn">lizhi</a>
 * @version 1.0, 2018-2-28
 * @description 户室信息表
 */
@Table(name = "ktt_lpb_fw_hs")
public class KttLpbFwHs {
    @Id
    private String fw_hs_index;//主键
    private String fw_dcb_index;//主键
    private String bdcdyh;//房间不动产单元编号
    private Integer wlcs;//物理层数
    private String fjh;//房间号
    private String dycs;//定义层数
    private String dyh;//单元号
    private Integer sxh;//室序号
    private Integer ch;//层号
    private Double cg;//层高
    private String qlid;//权利id
    private Double gytdmj;//共有土地面积
    private Double fttdmj;//分摊土地面积
    private Double dytdmj;//独用土地面积
    private Double ycjzmj;//预测建筑面积
    private Double yctnjzmj;//预测套内建筑面积
    private Double ycftjzmj;//预测分摊建筑面积
    private Double ycdxbfjzmj;//预测地下部分建筑面积
    private Double ycqtjzmj;//预测其它建筑面积
    private Double ycftxs;//预测分摊系数
    private Double scjzmj;//实测建筑面积
    private Double sctnjzmj;//实测套内建筑面积
    private Double scftjzmj;//实测分摊建筑面积
    private Double scdxbfjzmj;//实测地下部分建筑面积
    private Double scqtjzmj;//实测其它建筑面积
    private Double scftxs;//实测分摊系数
    private Double jyjg;//交易价格
    private String zl;//坐落
    private String ghyt;//规划用途
    private String ghyt2;//规划用途
    private String ghyt3;//规划用途
    private String fwlx;//房屋类型
    private String fwxz;//房屋性质
    private String d;//东
    private String n;//南
    private String x;//西
    private String b;//北
    private String cqly;//产权来源
    private String ysdm;//要素代码
    private String fjsm;//附加说明
    private String dcyj;//调查意见
    private String dcz;//调查者
    private Date dcsj;//调查时间
    private String fwhx;//房屋户型
    private String jczxcd;//建成时装修程度
    private String hxjg;//户型结构
    private String fcdah;//房产档案号
    private String qlzt;//权利状态
    private String hbfx;//合并方向
    private Integer hbhs;//合并户数
    private String gyqk;//共有情况
    private String sfcsbh;//是否从属编号
    private String fw_hst_index;//户室图主键
    private String bdczt;//不动产状态
    private String bz;//备注
    private String bgbh;//变更编号
    private String fwbm;//房屋编码

    public String getFw_hs_index() {
        return fw_hs_index;
    }

    public void setFw_hs_index(String fw_hs_index) {
        this.fw_hs_index = fw_hs_index;
    }

    public String getFw_dcb_index() {
        return fw_dcb_index;
    }

    public void setFw_dcb_index(String fw_dcb_index) {
        this.fw_dcb_index = fw_dcb_index;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public Integer getWlcs() {
        return wlcs;
    }

    public void setWlcs(Integer wlcs) {
        this.wlcs = wlcs;
    }

    public String getFjh() {
        return fjh;
    }

    public void setFjh(String fjh) {
        this.fjh = fjh;
    }

    public String getDycs() {
        return dycs;
    }

    public void setDycs(String dycs) {
        this.dycs = dycs;
    }

    public String getDyh() {
        return dyh;
    }

    public void setDyh(String dyh) {
        this.dyh = dyh;
    }

    public Integer getSxh() {
        return sxh;
    }

    public void setSxh(Integer sxh) {
        this.sxh = sxh;
    }

    public Integer getCh() {
        return ch;
    }

    public void setCh(Integer ch) {
        this.ch = ch;
    }

    public Double getCg() {
        return cg;
    }

    public void setCg(Double cg) {
        this.cg = cg;
    }

    public String getQlid() {
        return qlid;
    }

    public void setQlid(String qlid) {
        this.qlid = qlid;
    }

    public Double getGytdmj() {
        return gytdmj;
    }

    public void setGytdmj(Double gytdmj) {
        this.gytdmj = gytdmj;
    }

    public Double getFttdmj() {
        return fttdmj;
    }

    public void setFttdmj(Double fttdmj) {
        this.fttdmj = fttdmj;
    }

    public Double getDytdmj() {
        return dytdmj;
    }

    public void setDytdmj(Double dytdmj) {
        this.dytdmj = dytdmj;
    }

    public Double getYcjzmj() {
        return ycjzmj;
    }

    public void setYcjzmj(Double ycjzmj) {
        this.ycjzmj = ycjzmj;
    }

    public Double getYctnjzmj() {
        return yctnjzmj;
    }

    public void setYctnjzmj(Double yctnjzmj) {
        this.yctnjzmj = yctnjzmj;
    }

    public Double getYcftjzmj() {
        return ycftjzmj;
    }

    public void setYcftjzmj(Double ycftjzmj) {
        this.ycftjzmj = ycftjzmj;
    }

    public Double getYcdxbfjzmj() {
        return ycdxbfjzmj;
    }

    public void setYcdxbfjzmj(Double ycdxbfjzmj) {
        this.ycdxbfjzmj = ycdxbfjzmj;
    }

    public Double getYcqtjzmj() {
        return ycqtjzmj;
    }

    public void setYcqtjzmj(Double ycqtjzmj) {
        this.ycqtjzmj = ycqtjzmj;
    }

    public Double getYcftxs() {
        return ycftxs;
    }

    public void setYcftxs(Double ycftxs) {
        this.ycftxs = ycftxs;
    }

    public Double getScjzmj() {
        return scjzmj;
    }

    public void setScjzmj(Double scjzmj) {
        this.scjzmj = scjzmj;
    }

    public Double getSctnjzmj() {
        return sctnjzmj;
    }

    public void setSctnjzmj(Double sctnjzmj) {
        this.sctnjzmj = sctnjzmj;
    }

    public Double getScftjzmj() {
        return scftjzmj;
    }

    public void setScftjzmj(Double scftjzmj) {
        this.scftjzmj = scftjzmj;
    }

    public Double getScdxbfjzmj() {
        return scdxbfjzmj;
    }

    public void setScdxbfjzmj(Double scdxbfjzmj) {
        this.scdxbfjzmj = scdxbfjzmj;
    }

    public Double getScqtjzmj() {
        return scqtjzmj;
    }

    public void setScqtjzmj(Double scqtjzmj) {
        this.scqtjzmj = scqtjzmj;
    }

    public Double getScftxs() {
        return scftxs;
    }

    public void setScftxs(Double scftxs) {
        this.scftxs = scftxs;
    }

    public Double getJyjg() {
        return jyjg;
    }

    public void setJyjg(Double jyjg) {
        this.jyjg = jyjg;
    }

    public String getZl() {
        return zl;
    }

    public void setZl(String zl) {
        this.zl = zl;
    }

    public String getGhyt() {
        return ghyt;
    }

    public void setGhyt(String ghyt) {
        this.ghyt = ghyt;
    }

    public String getGhyt2() {
        return ghyt2;
    }

    public void setGhyt2(String ghyt2) {
        this.ghyt2 = ghyt2;
    }

    public String getGhyt3() {
        return ghyt3;
    }

    public void setGhyt3(String ghyt3) {
        this.ghyt3 = ghyt3;
    }

    public String getFwlx() {
        return fwlx;
    }

    public void setFwlx(String fwlx) {
        this.fwlx = fwlx;
    }

    public String getFwxz() {
        return fwxz;
    }

    public void setFwxz(String fwxz) {
        this.fwxz = fwxz;
    }

    public String getD() {
        return d;
    }

    public void setD(String d) {
        this.d = d;
    }

    public String getN() {
        return n;
    }

    public void setN(String n) {
        this.n = n;
    }

    public String getX() {
        return x;
    }

    public void setX(String x) {
        this.x = x;
    }

    public String getB() {
        return b;
    }

    public void setB(String b) {
        this.b = b;
    }

    public String getCqly() {
        return cqly;
    }

    public void setCqly(String cqly) {
        this.cqly = cqly;
    }

    public String getYsdm() {
        return ysdm;
    }

    public void setYsdm(String ysdm) {
        this.ysdm = ysdm;
    }

    public String getFjsm() {
        return fjsm;
    }

    public void setFjsm(String fjsm) {
        this.fjsm = fjsm;
    }

    public String getDcyj() {
        return dcyj;
    }

    public void setDcyj(String dcyj) {
        this.dcyj = dcyj;
    }

    public String getDcz() {
        return dcz;
    }

    public void setDcz(String dcz) {
        this.dcz = dcz;
    }

    public Date getDcsj() {
        return dcsj;
    }

    public void setDcsj(Date dcsj) {
        this.dcsj = dcsj;
    }

    public String getFwhx() {
        return fwhx;
    }

    public void setFwhx(String fwhx) {
        this.fwhx = fwhx;
    }

    public String getJczxcd() {
        return jczxcd;
    }

    public void setJczxcd(String jczxcd) {
        this.jczxcd = jczxcd;
    }

    public String getHxjg() {
        return hxjg;
    }

    public void setHxjg(String hxjg) {
        this.hxjg = hxjg;
    }

    public String getFcdah() {
        return fcdah;
    }

    public void setFcdah(String fcdah) {
        this.fcdah = fcdah;
    }

    public String getQlzt() {
        return qlzt;
    }

    public void setQlzt(String qlzt) {
        this.qlzt = qlzt;
    }

    public String getHbfx() {
        return hbfx;
    }

    public void setHbfx(String hbfx) {
        this.hbfx = hbfx;
    }

    public Integer getHbhs() {
        return hbhs;
    }

    public void setHbhs(Integer hbhs) {
        this.hbhs = hbhs;
    }

    public String getGyqk() {
        return gyqk;
    }

    public void setGyqk(String gyqk) {
        this.gyqk = gyqk;
    }

    public String getSfcsbh() {
        return sfcsbh;
    }

    public void setSfcsbh(String sfcsbh) {
        this.sfcsbh = sfcsbh;
    }

    public String getFw_hst_index() {
        return fw_hst_index;
    }

    public void setFw_hst_index(String fw_hst_index) {
        this.fw_hst_index = fw_hst_index;
    }

    public String getBdczt() {
        return bdczt;
    }

    public void setBdczt(String bdczt) {
        this.bdczt = bdczt;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getBgbh() {
        return bgbh;
    }

    public void setBgbh(String bgbh) {
        this.bgbh = bgbh;
    }

    public String getFwbm() {
        return fwbm;
    }

    public void setFwbm(String fwbm) {
        this.fwbm = fwbm;
    }
}

==> estateplat-common-1.2.3-20180919.074355-188-sources.jar: cn/gtmap/estateplat/model/exchange/national/KttLpbFwHs.java <==
package cn.gtmap.estateplat.model.exchange.national;

import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;

/**
 * @author <a href="mailto:sunchao@gtmap.cn">lizhi</a>
 * @version 1.0, 2018-2-28
 * @description 户室信息表
 */
@Table(name = "ktt_lpb_fw_hs")
public class KttLpbFwHs {
    @Id
    private String fw_hs_index;//主键
    private String fw_dcb_index;//主键
    private String bdcdyh;//房间不动产单元编号
    private Integer wlcs;//物理层数
    private String fjh;//房间号
    private String dycs;//定义层数
    private String dyh;//单元号
    private Integer sxh;//室序号
    private Integer ch;//层号
    private Double cg;//层高
    private String qlid;//权利id
    private Double gytdmj;//共有土地面积
    private Double fttdmj;//分摊土地面积
    private Double dytdmj;//独用土地面积
    private Double ycjzmj;//预测建筑面积
    private Double yctnjzmj;//预测套内建筑面积
    private Double ycftjzmj;//预测分摊建筑面积
    private Double ycdxbfjzmj;//预测地下部分建筑面积
    private Double ycqtjzmj;//预测其它建筑面积
    private Double ycftxs;//预测分摊系数
    private Double scjzmj;//实测建筑面积
    private Double sctnjzmj;//实测套内建筑面积
    private Double scftjzmj;//实测分摊建筑面积
    private Double scdxbfjzmj;//实测地下部分建筑面积
    private Double scqtjzmj;//实测其它建筑面积
    private Double scftxs;//实测分摊系数
    private Double jyjg;//交易价格
    private String zl;//坐落
    private String ghyt;//规划用途
    private String ghyt2;//规划用途
    private String ghyt3;//规划用途
    private String fwlx;//房屋类型
    private String fwxz;//房屋性质
    private String d;//东
    private String n;//南
    private String x;//西
    private String b;//北
    private String cqly;//产权来源
    private String ysdm;//要素代码
    private String fjsm;//附加说明
    private String dcyj;//调查意见
    private String dcz;//调查者
    private Date dcsj;//调查时间
    private String fwhx;//房屋户型
    private String jczxcd;//建成时装修程度
    private String hxjg;//户型结构
    private String fcdah;//房产档案号
    private String qlzt;//权利状态
    private String hbfx;//合并方向
    private Integer hbhs;//合并户数
    private String gyqk;//共有情况
    private String sfcsbh;//是否从属编号
    private String fw_hst_index;//户室图主键
    private String bdczt;//不动产状态
    private String bz;//备注
    private String bgbh;//变更编号
    private String fwbm;//房屋编码
    private Double sucmoney;//总价格

    public String getFw_hs_index() {
        return fw_hs_index;
    }

    public void setFw_hs_index(String fw_hs_index) {
        this.fw_hs_index = fw_hs_index;
    }

    public String getFw_dcb_index() {
        return fw_dcb_index;
    }

    public void setFw_dcb_index(String fw_dcb_index) {
        this.fw_dcb_index = fw_dcb_index;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public Integer getWlcs() {
        return wlcs;
    }

    public void setWlcs(Integer wlcs) {
        this.wlcs = wlcs;
    }

    public String getFjh() {
        return fjh;
    }

    public void setFjh(String fjh) {
        this.fjh = fjh;
    }

    public String getDycs() {
        return dycs;
    }

    public void setDycs(String dycs) {
        this.dycs = dycs;
    }

    public String getDyh() {
        return dyh;
    }

    public void setDyh(String dyh) {
        this.dyh = dyh;
    }

    public Integer getSxh() {
        return sxh;
    }

    public void setSxh(Integer sxh) {
        this.sxh = sxh;
    }

    public Integer getCh() {
        return ch;
    }

    public void setCh(Integer ch) {
        this.ch = ch;
    }

    public Double getCg() {
        return cg;
    }

    public void setCg(Double cg) {
        this.cg = cg;
    }

    public String getQlid() {
        return qlid;
    }

    public void setQlid(String qlid) {
        this.qlid = qlid;
    }

    public Double getGytdmj() {
        return gytdmj;
    }

    public void setGytdmj(Double gytdmj) {
        this.gytdmj = gytdmj;
    }

    public Double getFttdmj() {
        return fttdmj;
    }

    public void setFttdmj(Double fttdmj) {
        this.fttdmj = fttdmj;
    }

    public Double getDytdmj() {
        return dytdmj;
    }

    public void setDytdmj(Double dytdmj) {
        this.dytdmj = dytdmj;
    }

    public Double getYcjzmj() {
        return ycjzmj;
    }

    public void setYcjzmj(Double ycjzmj) {
        this.ycjzmj = ycjzmj;
    }

    public Double getYctnjzmj() {
        return yctnjzmj;
    }

    public void setYctnjzmj(Double yctnjzmj) {
        this.yctnjzmj = yctnjzmj;
    }

    public Double getYcftjzmj() {
        return ycftjzmj;
    }

    public void setYcftjzmj(Double ycftjzmj) {
        this.ycftjzmj = ycftjzmj;
    }

    public Double getYcdxbfjzmj() {
        return ycdxbfjzmj;
    }

    public void setYcdxbfjzmj(Double ycdxbfjzmj) {
        this.ycdxbfjzmj = ycdxbfjzmj;
    }

    public Double getYcqtjzmj() {
        return ycqtjzmj;
    }

    public void setYcqtjzmj(Double ycqtjzmj) {
        this.ycqtjzmj = ycqtjzmj;
    }

    public Double getYcftxs() {
        return ycftxs;
    }

    public void setYcftxs(Double ycftxs) {
        this.ycftxs = ycftxs;
    }

    public Double getScjzmj() {
        return scjzmj;
    }

    public void setScjzmj(Double scjzmj) {
        this.scjzmj = scjzmj;
    }

    public Double getSctnjzmj() {
        return sctnjzmj;
    }

    public void setSctnjzmj(Double sctnjzmj) {
        this.sctnjzmj = sctnjzmj;
    }

    public Double getScftjzmj() {
        return scftjzmj;
    }

    public void setScftjzmj(Double scftjzmj) {
        this.scftjzmj = scftjzmj;
    }

    public Double getScdxbfjzmj() {
        return scdxbfjzmj;
    }

    public void setScdxbfjzmj(Double scdxbfjzmj) {
        this.scdxbfjzmj = scdxbfjzmj;
    }

    public Double getScqtjzmj() {
        return scqtjzmj;
    }

    public void setScqtjzmj(Double scqtjzmj) {
        this.scqtjzmj = scqtjzmj;
    }

    public Double getScftxs() {
        return scftxs;
    }

    public void setScftxs(Double scftxs) {
        this.scftxs = scftxs;
    }

    public Double getJyjg() {
        return jyjg;
    }

    public void setJyjg(Double jyjg) {
        this.jyjg = jyjg;
    }

    public String getZl() {
        return zl;
    }

    public void setZl(String zl) {
        this.zl = zl;
    }

    public String getGhyt() {
        return ghyt;
    }

    public void setGhyt(String ghyt) {
        this.ghyt = ghyt;
    }

    public String getGhyt2() {
        return ghyt2;
    }

    public void setGhyt2(String ghyt2) {
        this.ghyt2 = ghyt2;
    }

    public String getGhyt3() {
        return ghyt3;
    }

    public void setGhyt3(String ghyt3) {
        this.ghyt3 = ghyt3;
    }

    public String getFwlx() {
        return fwlx;
    }

    public void setFwlx(String fwlx) {
        this.fwlx = fwlx;
    }

    public String getFwxz() {
        return fwxz;
    }

    public void setFwxz(String fwxz) {
        this.fwxz = fwxz;
    }

    public String getD() {
        return d;
    }

    public void setD(String d) {
        this.d = d;
    }

    public String getN() {
        return n;
    }

    public void setN(String n) {
        this.n = n;
    }

    public String getX() {
        return x;
    }

    public void setX(String x) {
        this.x = x;
    }

    public String getB() {
        return b;
    }

    public void setB(String b) {
        this.b = b;
    }

    public String getCqly() {
        return cqly;
    }

    public void setCqly(String cqly) {
        this.cqly = cqly;
    }

    public String getYsdm() {
        return ysdm;
    }

    public void setYsdm(String ysdm) {
        this.ysdm = ysdm;
    }

    public String getFjsm() {
        return fjsm;
    }

    public void setFjsm(String fjsm) {
        this.fjsm = fjsm;
    }

    public String getDcyj() {
        return dcyj;
    }

    public void setDcyj(String dcyj) {
        this.dcyj = dcyj;
    }

    public String getDcz() {
        return dcz;
    }

    public void setDcz(String dcz) {
        this.dcz = dcz;
    }

    public Date getDcsj() {
        return dcsj;
    }

    public void setDcsj(Date dcsj) {
        this.dcsj = dcsj;
    }

    public String getFwhx() {
        return fwhx;
    }

    public void setFwhx(String fwhx) {
        this.fwhx = fwhx;
    }

    public String getJczxcd() {
        return jczxcd;
    }

    public void setJczxcd(String jczxcd) {
        this.jczxcd = jczxcd;
    }

    public String getHxjg() {
        return hxjg;
    }

    public void setHxjg(String hxjg) {
        this.hxjg = hxjg;
    }

    public String getFcdah() {
        return fcdah;
    }

    public void setFcdah(String fcdah) {
        this.fcdah = fcdah;
    }

    public String getQlzt() {
        return qlzt;
    }

    public void setQlzt(String qlzt) {
        this.qlzt = qlzt;
    }

    public String getHbfx() {
        return hbfx;
    }

    public void setHbfx(String hbfx) {
        this.hbfx = hbfx;
    }

    public Integer getHbhs() {
        return hbhs;
    }

    public void setHbhs(Integer hbhs) {
        this.hbhs = hbhs;
    }

    public String getGyqk() {
        return gyqk;
    }

    public void setGyqk(String gyqk) {
        this.gyqk = gyqk;
    }

    public String getSfcsbh() {
        return sfcsbh;
    }

    public void setSfcsbh(String sfcsbh) {
        this.sfcsbh = sfcsbh;
    }

    public String getFw_hst_index() {
        return fw_hst_index;
    }

    public void setFw_hst_index(String fw_hst_index) {
        this.fw_hst_index = fw_hst_index;
    }

    public String getBdczt() {
        return bdczt;
    }

    public void setBdczt(String bdczt) {
        this.bdczt = bdczt;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getBgbh() {
        return bgbh;
    }

    public void setBgbh(String bgbh) {
        this.bgbh = bgbh;
    }

    public String getFwbm() {
        return fwbm;
    }

    public void setFwbm(String fwbm) {
        this.fwbm = fwbm;
    }

    public Double getSucmoney() {
        return sucmoney;
    }

    public void setSucmoney(Double sucmoney) {
        this.sucmoney = sucmoney;
    }
}
